// regex para validar distintos formatos
const regex = {
  telefono: /^[0-9\b]+$/,
  rfc: /^[A-Z0-9\b]+$/,
  letras: /^[a-zA-Z\s]*$/,
  alfanumerico: /^[a-zA-Z0-9\s]*$/,
  url: /^(http|https):\/\/[^ "]+$/,
  numero: /^[0-9]*$/,
  decimal: /^\d+(\.\d{1,2})?$/,
  fecha: /^\d{4}-\d{2}-\d{2}$/,
  hora: /^([01]?[0-9]|2[0-3]):[0-5][0-9]$/,
  curp: /^[A-Z]{4}\d{6}[HM][A-Z]{5}[A-Z0-9]{2}$/,
};

// reglas comunes para validaciones de formularios en Ant Design
const commonRules = {
  requerido: { required: true, message: 'Este campo es obligatorio.' },
  correo: { type: 'email', message: 'El correo electrónico no es válido' },
  telefono: [
    { min: 10, max: 10, message: 'El número de teléfono debe tener 10 dígitos' },
    { pattern: regex.telefono, message: 'El número de teléfono debe contener solo números' }
  ],
  numero: { type: 'number', message: 'El valor debe ser un número' },
  password: { min: 6, message: 'La contraseña debe tener al menos 6 caracteres' },
  rfc: [
    { min: 12, max: 13, message: 'El RFC debe tener entre 12 y 13 caracteres' },
    { pattern: regex.rfc, message: 'El RFC debe contener solo números y letras mayúsculas' }
  ],
  letras: { pattern: regex.letras, message: 'Este campo solo puede contener letras' },
  url: { type: 'url', message: 'La URL no es válida' },
  longitud: (min, max) => ({ min, max, message: `Este campo debe tener entre ${min} y ${max} caracteres` }),
  longitudMin: min => ({ min, message: `Este campo debe tener al menos ${min} caracteres` }),
  longitudMax: max => ({ max, message: `Este campo debe tener máximo ${max} caracteres` }),
  rango: (min, max) => ({ type: 'number', min, max, message: `El valor debe estar entre ${min} y ${max}` }),
  rangoMin: min => ({ type: 'number', min, message: `El valor debe ser mayor o igual a ${min}` }),
  rangoMax: max => ({ type: 'number', max, message: `El valor debe ser menor o igual a ${max}` }),
  formato: (regex, message) => ({ pattern: regex, message }),
  comparar: (field, message) => ({
    validator: (rule, value, callback) => {
      if (value && value !== field) {
        callback(message);
      } else {
        callback();
      }
    }
  })
}

export {
  commonRules
};