import { Form, Input, Button, Spin, Space, Row, Col } from "antd";
import { useEffect, useMemo, useState } from "react";
import HttpService from "../../../services/httpService";
import { respuestas } from "../../../utilities";
import { useNavigate } from "react-router-dom";
import { useQuery, useModel } from "../../../hooks";
import { commonRules } from "../../../constants/rules";
import { MinusCircleOutlined, PlusOutlined } from "@ant-design/icons";

const endpoints = {
  producto: "producto",
};

const ProductoDetalle = () => {
  const [form] = Form.useForm();
  const navigate = useNavigate();
  const [loading, setLoading] = useState(false);
  const query = useQuery();
  const id = query.get("id");
  const [request, setRequest] = useState({});

  const requestParams = useMemo(
    () => ({
      name: endpoints.producto,
      expand: "subproductos",
      id,
    }),
    [id]
  );

  const { model, modelLoading } = useModel(request);

  useEffect(() => {
    if (id) {
      setRequest(requestParams);
    }
    return () => {
      setRequest({});
    };
  }, [id, requestParams]);

  useEffect(() => {
    if (model) {
      form.setFieldsValue({
        //seteo cuando son varios
        ...model,
        subproductos: model.subproductos.map((subproducto, index) => ({
          ...subproducto,
          key: index,
        })),
      });
    }
  }, [form, model]);

  const onFinish = async (values) => {
    try {
      setLoading(true);

      let body = {
        ...values,
      };

      if (id) {
        body.id = id;
      }

      const res = await HttpService.post(`${endpoints.producto}/guardar`, body);
      respuestas(res);
      if (res?.status === 200) {
        navigate("/administracion/catalogos/productos");
      }
    } catch (error) {
      console.log(error);
      setLoading(false);
    } finally {
      setLoading(false);
    }
  };

  if (modelLoading) {
    return (
      <Spin
        size="large"
        style={{ display: "block", margin: "auto", marginTop: "50px" }}
      />
    );
  }

  const handleKeyPress = (event) => {
    const charCode = event.which ? event.which : event.keyCode;
    if (charCode < 48 || charCode > 57) {
      event.preventDefault();
    }
  };

  return (
    <Form
      layout="vertical"
      name="basic"
      form={form}
      onFinish={onFinish}
      onFinishFailed={() => {}}
    >
      <Row gutter={16}>
        <Col span={24}>
          <h2>Información del Producto</h2>
        </Col>
        <Col md={8} xs={12}>
          <Form.Item
            label="Nombre"
            name="nombre"
            rules={[commonRules.requerido]}
          >
            <Input />
          </Form.Item>
        </Col>
        <Col md={8} xs={12}>
          <Form.Item
            label="ID Sagarhpa"
            name="idSagarhpa"
            rules={[commonRules.requerido]}
          >
            <Input onKeyPress={handleKeyPress} maxLength={9} />
          </Form.Item>
        </Col>
        <Col span={24}>
          <h2>Subproductos:</h2>
        </Col>
        <Col span={24}>
          <Form.List name="subproductos">
            {(fields, { add, remove }) => (
              <>
                {fields.map(({ key, name, ...restField }) => (
                  <Row
                    key={key}
                    style={{ display: "flex", marginBottom: 12 }}
                    align="baseline"
                    gutter={[10, 10]}
                  >
                    <Col md={8} xs={24} lg={6}>
                      <Form.Item
                        {...restField}
                        name={[name, "nombre"]}
                        label="Nombre del Subproducto"
                        rules={[commonRules.requerido]}
                      >
                        <Input placeholder="Nombre del Subproducto" />
                      </Form.Item>
                    </Col>
                    <Col md={8} xs={24} lg={6}>
                      <Form.Item
                        {...restField}
                        name={[name, "idSagarhpa"]}
                        label="ID Subproducto"
                        rules={[commonRules.requerido]}
                      >
                        <Input onKeyPress={handleKeyPress} maxLength={9} />
                      </Form.Item>
                    </Col>
                    <Col md={8} xs={24} lg={6} style={{ marginTop: 35 }}>
                      <MinusCircleOutlined onClick={() => remove(name)} />
                    </Col>
                  </Row>
                ))}
                <Form.Item>
                  <Button
                    type="dashed"
                    onClick={() => add()}
                    icon={<PlusOutlined />}
                  >
                    Agregar Subproducto
                  </Button>
                </Form.Item>
              </>
            )}
          </Form.List>
        </Col>

        <Col span={24}>
          <Form.Item>
            <Button
              type="primary"
              htmlType="submit"
              style={{ marginTop: "30px" }}
              loading={loading}
            >
              Guardar
            </Button>
          </Form.Item>
        </Col>
      </Row>
    </Form>
  );
};

export default ProductoDetalle;
